==> af-common-elasticsearch-1.1.7.2-sources.jar: com/af/v4/system/common/elasticsearch/config/AFLogstashGlobalConfig.java <==
package com.af.v4.system.common.elasticsearch.config;

import com.af.v4.system.common.datasource.DynamicDataSource;
import com.alibaba.druid.pool.DruidDataSource;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

/**
 * 该类用于配置全局数据，数据源
 */
@Component
public class AFLogstashGlobalConfig {

    private final ElasticSearchConfig esConfig;
    @Value("${logstash.allFieldDefineName}")
    private String allFieldDefineName;
    @Value("${logstash.ESTargetIndex}")
    private String ESTargetIndex;
    @Value("${logstash.JDBCDriverPath}")
    private String JDBCDriverPath;

    public AFLogstashGlobalConfig(ElasticSearchConfig esConfig) {
        this.esConfig = esConfig;
    }

    public String getJDBCDriverClassName() {
        return DynamicDataSource.getDruidDataSource().getDriverClassName();
    }

    public String getDBType() {
        return DynamicDataSource.getDruidDataSource().getDbType();
    }

    public String getAllFieldDefineName() {
        return allFieldDefineName;
    }

    public String getESTargetIndex() {
        return ESTargetIndex;
    }

    public String getJDBCDriverPath() {
        return JDBCDriverPath;
    }

    public String getDBurl() {
        DruidDataSource dataSource = DynamicDataSource.getDruidDataSource();
        return dataSource.getUrl();
    }

    public String getDBUsername() {
        DruidDataSource dataSource = DynamicDataSource.getDruidDataSource();
        return dataSource.getUsername();
    }

    public String getDBPassword() {
        DruidDataSource dataSource = DynamicDataSource.getDruidDataSource();
        return dataSource.getPassword();
    }

    public String getESHost() {
        String host = esConfig.getHost();
        String port = esConfig.getPort();
        return host + ":" + port;
    }
}

==> af-common-elasticsearch-2.14.35-sources.jar: com/af/v4/system/common/elasticsearch/config/AFLogstashGlobalConfig.java <==
package com.af.v4.system.common.elasticsearch.config;

import com.af.v4.system.common.datasource.DynamicDataSource;
import com.af.v4.system.common.datasource.enums.DbType;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

/**
 * 该类用于配置全局数据，数据源
 */
@Component
public class AFLogstashGlobalConfig {

    private final ElasticSearchConfig esConfig;
    @Value("${logstash.allFieldDefineName}")
    private String allFieldDefineName;
    @Value("${logstash.ESTargetIndex}")
    private String ESTargetIndex;
    @Value("${logstash.JDBCDriverPath}")
    private String JDBCDriverPath;

    public AFLogstashGlobalConfig(ElasticSearchConfig esConfig) {
        this.esConfig = esConfig;
    }

    public String getJDBCDriverClassName() {
        return DynamicDataSource.getWrapper().getConfig().getDriverClassName();
    }

    public DbType getDBType() {
        return DynamicDataSource.getWrapper().getDbType();
    }

    public String getAllFieldDefineName() {
        return allFieldDefineName;
    }

    public String getESTargetIndex() {
        return ESTargetIndex;
    }

    public String getJDBCDriverPath() {
        return JDBCDriverPath;
    }

    public String getDBurl() {
        return DynamicDataSource.getWrapper().getConfig().getUrl();
    }

    public String getDBUsername() {
        return DynamicDataSource.getWrapper().getConfig().getUsername();
    }

    public String getDBPassword() {
        return DynamicDataSource.getWrapper().getConfig().getPassword();
    }

    public String getESHost() {
        String host = esConfig.getHost();
        String port = esConfig.getPort();
        return STR."\{host}:\{port}";
    }
}
